import 'package:dashboard/exceptions/login_exception.dart';
import 'package:dashboard/loading.dart';
import 'package:dashboard/ui/graphs/community_meta/cluster_view_page.dart';
import 'package:dashboard/ui/sign_in/loginpage.dart';
import 'package:dashboard/util/loginhelper.dart';
import 'package:dashboard/util/user.dart';
import 'package:enhanced_future_builder/enhanced_future_builder.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;

void main() {
  runApp(ArticonfDashboardDemo());
}

class ArticonfDashboardDemo extends StatefulWidget {
  @override
  _ArticonfDashboardDemoState createState() => _ArticonfDashboardDemoState();
}

class _ArticonfDashboardDemoState extends State<ArticonfDashboardDemo> {
  Future<BackendUser> _checkLoginStuff() async {
    try {
      return await LoginHelper().loggedInUser;
    } on LoginException {
      return null;
    }
  }

  @override
  Widget build(BuildContext context) {
    // ClusterGetter().getClusters();

    return MaterialApp(
      home: EnhancedFutureBuilder<BackendUser>(
        future: _checkLoginStuff(),
        whenNotDone: LoadingScreen(),
        rememberFutureResult: false,
        whenDone: (BackendUser snapshotData) {
          if (snapshotData == null) return LoginPage();
          return ClusterViewPage();
        },
      ),
    );
  }
}

class DemoWidget extends StatefulWidget {
  @override
  _DemoWidgetState createState() => _DemoWidgetState();
}

class _DemoWidgetState extends State<DemoWidget> {
  String _url = "http://rest-gateway/api/users";
  String _response;

  void _call() async {
    try {
      http.Response response = await http.get(_url);
      setState(() {
        _response = "${response.statusCode} - ${response.body}";
      });
    } catch (e, str) {
      setState(() {
        _response = "$e,\n\n $str";
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        body: Center(
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              TextFormField(
                initialValue: _url,
                onChanged: (value) => _url = value,
              ),
              SizedBox(height: 8),
              ElevatedButton(onPressed: _call, child: Text("Send Request")),
              SizedBox(height: 8),
              if (_url != null) Text(_response),
            ],
          ),
        ),
      ),
    );
  }
}
