import 'package:dashboard/querying/clustergetter.dart';
import 'package:dashboard/querying/communitygetter.dart';
import 'package:dashboard/ui/theme/color_holder.dart';
import 'package:dashboard/ui/util/logged_in_appbar.dart';
import 'package:enhanced_future_builder/enhanced_future_builder.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import '../../../loading.dart';
import 'cluster_graph.dart';
import 'index.dart';

class ClusterViewPage extends StatelessWidget {
  Widget build(BuildContext context) {
    return DefaultTabController(
      length: 5,
      child: Scaffold(
        appBar: LoggedInAppBar(
          "Cluster View",
          bottom: TabBar(
            tabs: [
              Text("Communities"),
              Text("Upvotes"),
              Text("Trust"),
              Text("Engagement"),
              Text("Time")
            ],
          ),
        ),
        backgroundColor: ColorHolder.color3,
        body: TabBarView(
          children: [
            Container(
              padding: EdgeInsets.all(12),
              constraints: BoxConstraints.expand(),
              child: EnhancedFutureBuilder(
                future: DataGetter.getCommunities(),
                rememberFutureResult: false,
                whenDone: (communities) => CommunityMetaGraph(communities),
                whenNotDone: Container(
                  alignment: Alignment.center,
                  child: LoadingScreen(
                    message: "Fetching Data...",
                  ),
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.all(12),
              constraints: BoxConstraints.expand(),
              child: EnhancedFutureBuilder(
                future: ClusterGetter().getClustersFromLayer("Upvotes_Layer"),
                rememberFutureResult: false,
                whenDone: (clusters) => ClusterGraph(clusters),
                whenNotDone: Container(
                  alignment: Alignment.center,
                  child: LoadingScreen(
                    message: "Fetching Data...",
                  ),
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.all(12),
              constraints: BoxConstraints.expand(),
              child: EnhancedFutureBuilder(
                future:
                    ClusterGetter().getClustersFromLayer("Percentage_Layer"),
                rememberFutureResult: false,
                whenDone: (clusters) => ClusterGraph(clusters),
                whenNotDone: Container(
                  alignment: Alignment.center,
                  child: LoadingScreen(
                    message: "Fetching Data...",
                  ),
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.all(12),
              constraints: BoxConstraints.expand(),
              child: EnhancedFutureBuilder(
                future:
                    ClusterGetter().getClustersFromLayer("Engagement_Layer"),
                rememberFutureResult: false,
                whenDone: (clusters) => ClusterGraph(clusters),
                whenNotDone: Container(
                  alignment: Alignment.center,
                  child: LoadingScreen(
                    message: "Fetching Data...",
                  ),
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.all(12),
              constraints: BoxConstraints.expand(),
              child: EnhancedFutureBuilder(
                future: ClusterGetter().getClustersFromLayer("Time_Layer"),
                rememberFutureResult: false,
                whenDone: (clusters) => ClusterGraph(clusters),
                whenNotDone: Container(
                  alignment: Alignment.center,
                  child: LoadingScreen(
                    message: "Fetching Data...",
                  ),
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
