import 'package:animated_text_kit/animated_text_kit.dart';
import 'package:dashboard/constants/schema_demo_constants.dart';
import 'package:flutter/material.dart';

enum PostStatus { WRITING, SENDING, DONE }

class WrittenPost extends StatefulWidget {
  @override
  _WrittenPostState createState() => _WrittenPostState();

  final TextStyle style = TextStyle(
    color: Colors.black,
    fontSize: 16,
    fontWeight: FontWeight.normal,
  );

  final Function onDone;
  final PostStatus initialStatus;
  final Duration pauseBetweenCharacters = Duration(milliseconds: 10);

  WrittenPost(this.onDone, {this.initialStatus = PostStatus.WRITING});
}

class _WrittenPostState extends State<WrittenPost> {
  PostStatus _status;

  void initState() {
    _status = widget.initialStatus;
    super.initState();
  }

  void _onWritingDone() {
    setState(() {
      _status = PostStatus.SENDING;
    });

    Future.delayed(Duration(milliseconds: 500))
        .then((value) => _onSendingDone());
  }

  void _onSendingDone() {
    setState(() {
      _status = PostStatus.DONE;
    });

    if (widget.onDone != null) widget.onDone();
  }

  @override
  Widget build(BuildContext context) {
    return Hero(
      tag: "post_written",
      child: SizedBox(
        height: 270,
        width: 400,
        child: Card(
          child: Padding(
            padding: const EdgeInsets.all(8.0),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Text(
                  "New Post",
                  style: TextStyle(
                    fontWeight: FontWeight.bold,
                    fontSize: 22,
                  ),
                ),
                Divider(),
                Expanded(
                  child: _status == PostStatus.WRITING
                      ? TypewriterAnimatedTextKit(
                          speed: widget.pauseBetweenCharacters,
                          totalRepeatCount: 1,
                          text: [SchemaDemoConstants.post],
                          pause: Duration(milliseconds: 200),
                          textStyle: widget.style,
                          repeatForever: false,
                          onFinished: _onWritingDone,
                          textAlign: TextAlign.left,
                        )
                      : Text(
                          SchemaDemoConstants.post,
                          style: widget.style,
                        ),
                ),
                Divider(),
                _SendButton(_status),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

class _SendButton extends StatelessWidget {
  final PostStatus status;

  _SendButton(this.status);

  Widget _icon() {
    switch (status) {
      case PostStatus.WRITING:
        return Icon(
          Icons.edit,
          color: Colors.white,
        );
      case PostStatus.SENDING:
        return SizedBox(
          width: 20,
          height: 20,
          child: CircularProgressIndicator(
            valueColor: AlwaysStoppedAnimation<Color>(Colors.white),
          ),
        );
      case PostStatus.DONE:
      default:
        return Icon(
          Icons.check,
          color: Colors.white,
        );
    }
  }

  @override
  Widget build(BuildContext context) {
    return TextButton.icon(
      onPressed: () {},
      icon: Padding(
        padding: EdgeInsets.all(4),
        child: _icon(),
      ),
      style: TextButton.styleFrom(
        backgroundColor: status == PostStatus.WRITING
            ? Theme.of(context).primaryColor
            : Colors.grey,
      ),
      label: Padding(
        padding: EdgeInsets.only(top: 4, bottom: 4, right: 4),
        child: Text(
          "Submit",
          style: TextStyle(
            color: Colors.white,
          ),
        ),
      ),
    );
  }
}
